import {
  initVendorConsentsLoader,
  addVendorLoadedEventListener,
  loadComscore
} from '@adv-ui/vendor-by-consents-loader'
import getHotjarConfig from './hotjar/config'
import getOptimizelyConfig from './optimizely/config'
import getTealiumConfig from './tealium/config'

const COMSCORE_CLIENT_ID = '13013988'

const getPortal = () => {
  const match = window.location.href.match(/infojobs(\w*)\.(\w*)/)
  if (match) {
    const [, environment, portal] = match
    return {portal: portal === 'it' ? 'it' : 'es', environment}
  }
  return {portal: 'es', environment: 'qaaws'}
}

const loader = () => {
  const {portal, environment} = getPortal()
  const path = window.location.pathname
  const queryParams = window.location.search
  const {config: hotjarConfig, initScript: initHotjarScript} = getHotjarConfig({
    portal,
    path
  })
  const {config: optimizelyConfig} = getOptimizelyConfig({portal, path})

  const {config: tealiumConfig} = getTealiumConfig({
    portal,
    environment,
    queryParams
  })

  initHotjarScript()

  loadComscore({comscoreClientId: COMSCORE_CLIENT_ID})

  console.log({
    vendors: {
      ...hotjarConfig,
      ...optimizelyConfig,
      ...tealiumConfig
    }
  })

  initVendorConsentsLoader({
    vendors: {
      ...hotjarConfig,
      ...optimizelyConfig,
      ...tealiumConfig
    }
  })

  addVendorLoadedEventListener(({vendor}) => {
    vendor === 'hotjar' && console.log('hotjar has been loaded')
    vendor === 'optimizely' && console.log('optimizely has been loaded')
    vendor === 'tealium' && console.log('tealium has been loaded')
  })
}

export default loader
